$(function () {
    function loadPreview(file, $element) {
        var reader = new FileReader();

        reader.onload = function (e) {
            // get loaded data and render thumbnail.
            $element.attr('src', e.target.result);
        };

        // read the image file as a data URL.
        reader.readAsDataURL(file);
    };

    function uploadImage(file, onsuccess, onfail) {
        var formData = new FormData();
        formData.append('imageFile', file);

        $.ajax({
            url:         g_URLdir + 'handler/RequestsProcessing/imageUpload',
            data:        formData,
            processData: false,
            contentType: false,
            type:        'POST',
            dataType:    'json',
            error:       onfail,
            success:     function (res) {
                res.success ? onsuccess(res) : onfail();
            }
        });
    };

    $('#errButton').click(function () {
        $.get(g_URLdir + "window/support", initErrorDialog);
    });

    var errReady = true;
    const nullRequestID = -1;
    var requestID = nullRequestID;
    var hasImage = false;

    function initErrorDialog(data) {
        wnd.open(JSON.parse(data));

        if (this.isInit) return;
        this.isInit = true;

        var $uploadImage = $('#uploadImage');
        var $statusIcon = $('#status-icon');
        var $previewBlock = $('#errDialog').find('.Preview');
        var userMayUploadFile = true;

        $statusIcon.click(function () {
            if (userMayUploadFile)
                $uploadImage.click();
        });

        $uploadImage.change(function () {
            userMayUploadFile = false;

            var sourceImage = $uploadImage[0].files[0];
            loadPreview(sourceImage, $("#previewImage"));
            $statusIcon.attr('class', 'fa fa-circle-o-notch fa-lg fa-spin');
            uploadImage(sourceImage, onSuccessLoad, onFailedLoad);
        });

        function onSuccessLoad(response) {
            console.log('Load succeeded: ' + response.requestID);
            requestID = response.requestID;
            $previewBlock.show();
            $statusIcon.hide();
            hasImage = true;
        }

        function onFailedLoad() {
            console.log('Load failed');
            EventInspector.error('Невозможно загрузить изображение');
            $statusIcon.attr('class', 'fa fa-exclamation-circle text-danger fa-lg').show();

            setTimeout(function () {
                userMayUploadFile = true;
                $statusIcon.attr('class', 'fa fa-camera fa-lg').show();
            }, 3000);
            hasImage = false;
        }

        var $imagePreview = $('#imagePreviewContainer');
        var $removeImageButton = $('#removeImageButton');

        $previewBlock.hover(function () {
                $imagePreview.css('opacity', 1);
            }, function () {
                $imagePreview.css('opacity', 0);
            }
        );

        $removeImageButton.click(function () {
            $statusIcon.attr('class', 'fa fa-camera fa-lg').show();
            $previewBlock.hide();
            
            userMayUploadFile = true;
            requestID = nullRequestID;
            hasImage = false;
        });
    }

    initErrorDialog.isInit = false;

    $(document).on('click', '#dialogSendButton', function () {
        const jMessageEmail = $('#messageEMail');
        const jMessageTitle = $('#messageTitle');
        const jMessage = $('#message');
        const jSendBut = $('#dialogSendButton');
        if (!errReady)
            return;
        errReady = false;

        // Save and erase
        const mesEmail = jMessageEmail.val();
        const mesTitle = jMessageTitle.val();
        const mesText = jMessage.val();

        if (mesTitle.length <= 0 || mesText.length <= 0) {
            const vMessage = (mesTitle.length <= 0)
                ? 'Вы не ввели тему сообщения' : 'Вы не ввели сообщение';
            EventInspector.error(vMessage);
            errReady = true;
            return;
        }

        jMessage.prop('disabled', true);
        jMessageTitle.prop('disabled', true);
        jSendBut.prop('disabled', true);
        $.ajax({
            type:    "POST",
            url:     g_URLdir + "handler/RequestsProcessing/createRequest",
            data:    {
                email:     mesEmail,
                title:     mesTitle,
                text:      mesText,
                requestID: requestID,
                hasImage : hasImage
            },
            success: function (data) {
                errReady = true;
                data = $.parseJSON(data);

                if (data.success === true) {
                    EventInspector.success('Сообщение успешно отправлено!');
                    jMessageTitle.val('');
                    jMessage.val('');

                    wnd.hide();
                    requestID = nullRequestID;
                } else EventInspector.error('Сообщение не отправлено');
            },
            error: function () {
                EventInspector.error('Сообщение не отправлено');
            },
            complete: function () {
                jMessage.removeAttr('disabled');
                jMessageTitle.removeAttr('disabled');
                jSendBut.removeAttr('disabled');
            }
        });
    });
});
